@@ -11,6 +11,12 @@ main (int argc, char **argv)
   double *abscoeff = malloc (n * sizeof (double));
   size_t *p = malloc (n * sizeof (size_t));
 
+  gsl_wavelet *w;
+  gsl_wavelet_workspace *work;
+
+  w = gsl_wavelet_alloc (gsl_wavelet_daubechies, 4);
+  work = gsl_wavelet_workspace_alloc (n);
+
   FILE *f = fopen (argv[1], "r");
   for (i = 0; i < n; i++)
     {
@@ -18,25 +24,20 @@ main (int argc, char **argv)
     }
   fclose (f);
 
-  {
-    gsl_wavelet *w = gsl_wavelet_alloc (gsl_wavelet_daubechies, 4);
-    gsl_wavelet_workspace *work = gsl_wavelet_workspace_alloc (n);
-
-    gsl_wavelet_transform_forward (w, data, 1, n, work);
-
-    for (i = 0; i < n; i++)
-      {
-        abscoeff[i] = fabs (data[i]);
-      }
-
-    gsl_sort_index (p, abscoeff, 1, n);
-
-    for (i = 0; (i + nc) < n; i++)
-      data[p[i]] = 0;
-
-    gsl_wavelet_transform_inverse (w, data, 1, n, work);
-  }
+  gsl_wavelet_transform_forward (w, data, 1, n, work);
 
+  for (i = 0; i < n; i++)
+    {
+      abscoeff[i] = fabs (data[i]);
+    }
+  
+  gsl_sort_index (p, abscoeff, 1, n);
+  
+  for (i = 0; (i + nc) < n; i++)
+    data[p[i]] = 0;
+  
+  gsl_wavelet_transform_inverse (w, data, 1, n, work);
+  
   for (i = 0; i < n; i++)
     {
       printf ("%g\n", data[i]);
