@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* Author:  G. Jungman
@@ -145,7 +145,8 @@ test_eigenvalues (size_t N, const gsl_vector *eval, const gsl_vector * eval2,
     {
       double ei = gsl_vector_get (eval, i);
       double e2i = gsl_vector_get (eval2, i);
-      gsl_test_rel(ei, e2i, GSL_DBL_EPSILON, "%s, direct eigenvalue(%d), %s",
+      gsl_test_rel(ei, e2i, 10*GSL_DBL_EPSILON, 
+                   "%s, direct eigenvalue(%d), %s",
                    desc, i, desc2);
     }
 }
