@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* vector_bfgs.c -- Limited memory Broyden-Fletcher-Goldfarb-Shanno
@@ -141,8 +141,8 @@ vector_bfgs_alloc (void *vstate, size_t n)
 
 static int
 vector_bfgs_set (void *vstate, gsl_multimin_function_fdf * fdf,
-		 const gsl_vector * x, double *f, gsl_vector * gradient,
-		 double step_size, double tol)
+                 const gsl_vector * x, double *f, gsl_vector * gradient,
+                 double step_size, double tol)
 {
   vector_bfgs_state_t *state = (vector_bfgs_state_t *) vstate;
 
@@ -194,8 +194,8 @@ vector_bfgs_restart (void *vstate)
 
 static int
 vector_bfgs_iterate (void *vstate, gsl_multimin_function_fdf * fdf,
-		     gsl_vector * x, double *f,
-		     gsl_vector * gradient, gsl_vector * dx)
+                     gsl_vector * x, double *f,
+                     gsl_vector * gradient, gsl_vector * dx)
 {
   vector_bfgs_state_t *state = (vector_bfgs_state_t *) vstate;
 
@@ -244,7 +244,6 @@ vector_bfgs_iterate (void *vstate, gsl_multimin_function_fdf * fdf,
       *f = fc;
       gsl_vector_memcpy (x, x1);
       GSL_MULTIMIN_FN_EVAL_DF (fdf, x1, gradient);
-      state->g0norm = gsl_blas_dnrm2 (gradient);
       return GSL_SUCCESS;
     }
 
@@ -257,7 +256,7 @@ vector_bfgs_iterate (void *vstate, gsl_multimin_function_fdf * fdf,
      xb based on parabolic interpolation */
 
   intermediate_point (fdf, x, p, dir / pnorm, pg,
-		      stepa, stepc, fa, fc, x1, dx1, gradient, &stepb, &fb);
+                      stepa, stepc, fa, fc, x1, dx1, gradient, &stepb, &fb);
 
   if (stepb == 0.0)
     {
@@ -265,8 +264,8 @@ vector_bfgs_iterate (void *vstate, gsl_multimin_function_fdf * fdf,
     }
 
   minimize (fdf, x, p, dir / pnorm,
-	    stepa, stepb, stepc, fa, fb, fc, tol,
-	    x1, dx1, x2, dx, gradient, &(state->step), f, &g1norm);
+            stepa, stepb, stepc, fa, fb, fc, tol,
+            x1, dx1, x2, dx, gradient, &(state->step), f, &g1norm);
 
   gsl_vector_memcpy (x, x2);
 
@@ -331,7 +330,7 @@ vector_bfgs_iterate (void *vstate, gsl_multimin_function_fdf * fdf,
 }
 
 static const gsl_multimin_fdfminimizer_type vector_bfgs_type = {
-  "vector_bfgs",		/* name */
+  "vector_bfgs",                /* name */
   sizeof (vector_bfgs_state_t),
   &vector_bfgs_alloc,
   &vector_bfgs_set,
