@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* Author:  G. Jungman
@@ -147,7 +147,7 @@ gsl_odeiv_evolve_apply (gsl_odeiv_evolve * e,
 
       if (status) 
         {
-          return GSL_EBADFUNC;
+          return status;
         }
     }
 
