@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -53,12 +53,12 @@ double test_binomial_large_pdf (unsigned int n);
 double test_binomial_huge (void);
 double test_binomial_huge_pdf (unsigned int n);
 
-double test_binomial_tpe (void);
-double test_binomial_tpe_pdf (unsigned int n);
-double test_binomial_large_tpe (void);
-double test_binomial_large_tpe_pdf (unsigned int n);
-double test_binomial_huge_tpe (void);
-double test_binomial_huge_tpe_pdf (unsigned int n);
+double test_binomial_knuth (void);
+double test_binomial_knuth_pdf (unsigned int n);
+double test_binomial_large_knuth (void);
+double test_binomial_large_knuth_pdf (unsigned int n);
+double test_binomial_huge_knuth (void);
+double test_binomial_huge_knuth_pdf (unsigned int n);
 
 double test_cauchy (void);
 double test_cauchy_pdf (double x);
@@ -213,6 +213,10 @@ double test_weibull1_pdf (double x);
 
 gsl_rng *r_global;
 
+static gsl_ran_discrete_t *g1 = NULL;
+static gsl_ran_discrete_t *g2 = NULL;
+static gsl_ran_discrete_t *g3 = NULL;
+
 int
 main (void)
 {
@@ -318,11 +322,11 @@ main (void)
   testDiscretePDF (FUNC2 (poisson_large));
   testDiscretePDF (FUNC2 (bernoulli));
   testDiscretePDF (FUNC2 (binomial));
-  testDiscretePDF (FUNC2 (binomial_tpe));
+  testDiscretePDF (FUNC2 (binomial_knuth));
   testDiscretePDF (FUNC2 (binomial_large));
-  testDiscretePDF (FUNC2 (binomial_large_tpe));
+  testDiscretePDF (FUNC2 (binomial_large_knuth));
   testDiscretePDF (FUNC2 (binomial_huge));
-  testDiscretePDF (FUNC2 (binomial_huge_tpe));
+  testDiscretePDF (FUNC2 (binomial_huge_knuth));
   testDiscretePDF (FUNC2 (geometric));
   testDiscretePDF (FUNC2 (geometric1));
   testDiscretePDF (FUNC2 (hypergeometric1));
@@ -337,6 +341,11 @@ main (void)
   testDiscretePDF (FUNC2 (negative_binomial));
   testDiscretePDF (FUNC2 (pascal));
 
+  gsl_rng_free (r_global);
+  gsl_ran_discrete_free (g1);
+  gsl_ran_discrete_free (g2);
+  gsl_ran_discrete_free (g3);
+
   exit (gsl_test_summary ());
 }
 
@@ -604,13 +613,13 @@ test_binomial_pdf (unsigned int n)
 }
 
 double
-test_binomial_tpe (void)
+test_binomial_knuth (void)
 {
-  return gsl_ran_binomial_tpe (r_global, 0.3, 5);
+  return gsl_ran_binomial_knuth (r_global, 0.3, 5);
 }
 
 double
-test_binomial_tpe_pdf (unsigned int n)
+test_binomial_knuth_pdf (unsigned int n)
 {
   return gsl_ran_binomial_pdf (n, 0.3, 5);
 }
@@ -629,13 +638,13 @@ test_binomial_large_pdf (unsigned int n)
 }
 
 double
-test_binomial_large_tpe (void)
+test_binomial_large_knuth (void)
 {
-  return gsl_ran_binomial_tpe (r_global, 0.3, 55);
+  return gsl_ran_binomial_knuth (r_global, 0.3, 55);
 }
 
 double
-test_binomial_large_tpe_pdf (unsigned int n)
+test_binomial_large_knuth_pdf (unsigned int n)
 {
   return gsl_ran_binomial_pdf (n, 0.3, 55);
 }
@@ -654,13 +663,13 @@ test_binomial_huge_pdf (unsigned int n)
 }
 
 double
-test_binomial_huge_tpe (void)
+test_binomial_huge_knuth (void)
 {
-  return gsl_ran_binomial_tpe (r_global, 0.3, 5500);
+  return gsl_ran_binomial_knuth (r_global, 0.3, 5500);
 }
 
 double
-test_binomial_huge_tpe_pdf (unsigned int n)
+test_binomial_huge_knuth_pdf (unsigned int n)
 {
   return gsl_ran_binomial_pdf (n, 0.3, 5500);
 }
@@ -922,10 +931,6 @@ test_multinomial_moments (void)
 }
 
 
-static gsl_ran_discrete_t *g1 = NULL;
-static gsl_ran_discrete_t *g2 = NULL;
-static gsl_ran_discrete_t *g3 = NULL;
-
 double
 test_discrete1 (void)
 {
