@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -26,11 +26,12 @@
 #include <gsl/gsl_ieee_utils.h>
 
 void rng_test (const gsl_rng_type * T, unsigned long int seed, unsigned int n,
-	       unsigned long int result);
+               unsigned long int result);
 void rng_float_test (const gsl_rng_type * T);
 void generic_rng_test (const gsl_rng_type * T);
 void rng_state_test (const gsl_rng_type * T);
 void rng_parallel_state_test (const gsl_rng_type * T);
+void rng_read_write_test (const gsl_rng_type * T);
 int rng_max_test (gsl_rng * r, unsigned long int *kmax, unsigned long int ran_max) ;
 int rng_min_test (gsl_rng * r, unsigned long int *kmin, unsigned long int ran_min, unsigned long int ran_max) ;
 int rng_sum_test (gsl_rng * r, double *sigma);
@@ -62,18 +63,40 @@ main (void)
   rng_test (gsl_rng_transputer, 1, 10000, 1244127297UL);
   rng_test (gsl_rng_vax, 1, 10000, 3051034865UL);
 
+  /* Borosh13 test value from PARI: (1812433253^10000)%(2^32) */
   rng_test (gsl_rng_borosh13, 1, 10000, 2513433025UL);
-  rng_test (gsl_rng_fishman18, 1, 10000, 1626638977UL);
-  rng_test (gsl_rng_fishman2x, 1, 10000, 1158622502UL);
-  rng_test (gsl_rng_knuthran2, 1, 10000, 1182784902UL);
+
+  /* Fishman18 test value from PARI: (62089911^10000)%(2^31-1) */
+  rng_test (gsl_rng_fishman18, 1, 10000, 330402013UL);
+
+  /* Fishman2x test value from PARI: 
+     ((48271^10000)%(2^31-1) - (40692^10000)%(2^31-249))%(2^31-1) */
+  rng_test (gsl_rng_fishman2x, 1, 10000, 540133597UL);
+
+  /* Knuthran2 test value from PARI: 
+     { xn1=1; xn2=1; for (n=1,10000, 
+            xn = (271828183*xn1 - 314159269*xn2)%(2^31-1);
+            xn2=xn1; xn1=xn; print(xn); ) } */
+  rng_test (gsl_rng_knuthran2, 1, 10000, 1084477620UL);
+
+  /* Knuthran test value taken from p188 in Knuth Vol 2. 3rd Ed */
   rng_test (gsl_rng_knuthran, 310952, 1009 * 2009 + 1, 461390032);
+
+  /* Lecuyer21 test value from PARI: (40692^10000)%(2^31-249) */
   rng_test (gsl_rng_lecuyer21, 1, 10000, 2006618587UL);
+
+  /* Waterman14 test value from PARI: (1566083941^10000)%(2^32) */
   rng_test (gsl_rng_waterman14, 1, 10000, 3776680385UL);
 
   /* specific tests of known results for 10000 iterations with seed = 6 */
 
+  /* Coveyou test value from PARI:
+     x=6; for(n=1,10000,x=(x*(x+1))%(2^32);print(x);) */
+
   rng_test (gsl_rng_coveyou, 6, 10000, 1416754246UL);
-  rng_test (gsl_rng_fishman20, 6, 10000, 1811577350UL);
+
+  /* Fishman20 test value from PARI: (6*48271^10000)%(2^31-1) */
+  rng_test (gsl_rng_fishman20, 6, 10000, 248127575UL);
 
   /* FIXME: the ranlux tests below were made by running the fortran code and
      getting the expected value from that. An analytic calculation
@@ -163,6 +186,9 @@ main (void)
   for (r = rngs ; *r != 0; r++)
     rng_parallel_state_test (*r);
 
+  for (r = rngs ; *r != 0; r++)
+    rng_read_write_test (*r);
+
   /* generic statistical tests (these are just to make sure that we
      don't get any crazy results back from the generator, i.e. they
      aren't a test of the algorithm, just the implementation) */
@@ -176,7 +202,7 @@ main (void)
 
 void
 rng_test (const gsl_rng_type * T, unsigned long int seed, unsigned int n,
-	  unsigned long int result)
+          unsigned long int result)
 {
   gsl_rng *r = gsl_rng_alloc (T);
   unsigned int i;
@@ -195,7 +221,7 @@ rng_test (const gsl_rng_type * T, unsigned long int seed, unsigned int n,
 
   status = (k != result);
   gsl_test (status, "%s, %u steps (%u observed vs %u expected)",
-	    gsl_rng_name (r), n, k, result);
+            gsl_rng_name (r), n, k, result);
 
   gsl_rng_free (r);
 }
@@ -224,14 +250,14 @@ rng_float_test (const gsl_rng_type * T)
       k = gsl_rng_get (ri);
       u = gsl_rng_get (rf);
       if (c*k != u)
-	{
-	  status = 1 ;
-	  break ;
-	}
+        {
+          status = 1 ;
+          break ;
+        }
     }
 
   gsl_test (status, "%s, ratio of int to double (%g observed vs %g expected)",
-	    gsl_rng_name (ri), c, k/u);
+            gsl_rng_name (ri), c, k/u);
 
   gsl_rng_free (ri);
   gsl_rng_free (rf);
@@ -250,17 +276,17 @@ rng_state_test (const gsl_rng_type * T)
 
   for (i = 0; i < N; ++i)
     {
-      gsl_rng_get (r);	/* throw away N iterations */
+      gsl_rng_get (r);  /* throw away N iterations */
     }
 
-  gsl_rng_memcpy (r_save, r);	/* save the intermediate state */
+  gsl_rng_memcpy (r_save, r);   /* save the intermediate state */
 
   for (i = 0; i < N; ++i)
     {
       test_a[i] = gsl_rng_get (r);
     }
 
-  gsl_rng_memcpy (r, r_save);	/* restore the intermediate state */
+  gsl_rng_memcpy (r, r_save);   /* restore the intermediate state */
   gsl_rng_free (r_save);
 
   for (i = 0; i < N; ++i)
@@ -272,10 +298,10 @@ rng_state_test (const gsl_rng_type * T)
     int status = 0;
     for (i = 0; i < N; ++i)
       {
-	status |= (test_b[i] != test_a[i]);
+        status |= (test_b[i] != test_a[i]);
       }
     gsl_test (status, "%s, random number state consistency",
-	      gsl_rng_name (r));
+              gsl_rng_name (r));
   }
 
   gsl_rng_free (r);
@@ -296,19 +322,19 @@ rng_parallel_state_test (const gsl_rng_type * T)
 
   for (i = 0; i < N; ++i)
     {
-      gsl_rng_get (r1);		/* throw away N iterations */
+      gsl_rng_get (r1);         /* throw away N iterations */
     }
 
-  gsl_rng_memcpy (r2, r1);		/* save the intermediate state */
+  gsl_rng_memcpy (r2, r1);              /* save the intermediate state */
 
   for (i = 0; i < N; ++i)
     {
       /* check that there is no hidden state intermixed between r1 and r2 */
-      test_a[i] = gsl_rng_get (r1);	
+      test_a[i] = gsl_rng_get (r1);     
       test_b[i] = gsl_rng_get (r2);
-      test_c[i] = gsl_rng_uniform_int (r1, 1234);	
+      test_c[i] = gsl_rng_uniform_int (r1, 1234);       
       test_d[i] = gsl_rng_uniform_int (r2, 1234);
-      test_e[i] = gsl_rng_uniform (r1);	
+      test_e[i] = gsl_rng_uniform (r1); 
       test_f[i] = gsl_rng_uniform (r2);
     }
 
@@ -316,12 +342,12 @@ rng_parallel_state_test (const gsl_rng_type * T)
     int status = 0;
     for (i = 0; i < N; ++i)
       {
-	status |= (test_b[i] != test_a[i]);
-	status |= (test_c[i] != test_d[i]);
-	status |= (test_e[i] != test_f[i]);
+        status |= (test_b[i] != test_a[i]);
+        status |= (test_c[i] != test_d[i]);
+        status |= (test_e[i] != test_f[i]);
       }
     gsl_test (status, "%s, parallel random number state consistency",
-	      gsl_rng_name (r1));
+              gsl_rng_name (r1));
   }
 
   gsl_rng_free (r1);
@@ -329,6 +355,55 @@ rng_parallel_state_test (const gsl_rng_type * T)
 
 }
 
+void
+rng_read_write_test (const gsl_rng_type * T)
+{
+  unsigned long int test_a[N], test_b[N];
+
+  int i;
+
+  gsl_rng *r = gsl_rng_alloc (T);
+
+  for (i = 0; i < N; ++i)
+    {
+      gsl_rng_get (r);  /* throw away N iterations */
+    }
+
+  { /* save the state to a binary file */
+    FILE *f = fopen("test.dat", "wb"); 
+    gsl_rng_fwrite(f, r);
+    fclose(f);
+  }
+
+  for (i = 0; i < N; ++i)
+    {
+      test_a[i] = gsl_rng_get (r);
+    }
+
+  { /* read the state from a binary file */
+    FILE *f = fopen("test.dat", "rb"); 
+    gsl_rng_fread(f, r);
+    fclose(f);
+  }
+
+  for (i = 0; i < N; ++i)
+    {
+      test_b[i] = gsl_rng_get (r);
+    }
+
+  {
+    int status = 0;
+    for (i = 0; i < N; ++i)
+      {
+        status |= (test_b[i] != test_a[i]);
+      }
+    gsl_test (status, "%s, random number generator read and write",
+              gsl_rng_name (r));
+  }
+
+  gsl_rng_free (r);
+}
+
 void
 generic_rng_test (const gsl_rng_type * T)
 {
@@ -342,43 +417,43 @@ generic_rng_test (const gsl_rng_type * T)
   int status = rng_max_test (r, &kmax, ran_max);
 
   gsl_test (status,
-	    "%s, observed vs theoretical maximum (%lu vs %lu)",
-	    name, kmax, ran_max);
+            "%s, observed vs theoretical maximum (%lu vs %lu)",
+            name, kmax, ran_max);
 
   status = rng_min_test (r, &kmin, ran_min, ran_max);
 
   gsl_test (status,
-	    "%s, observed vs theoretical minimum (%lu vs %lu)",
-	    name, kmin, ran_min);
+            "%s, observed vs theoretical minimum (%lu vs %lu)",
+            name, kmin, ran_min);
 
   status = rng_sum_test (r, &sigma);
 
   gsl_test (status,
-	    "%s, sum test within acceptable sigma (observed %.2g sigma)",
-	    name, sigma);
+            "%s, sum test within acceptable sigma (observed %.2g sigma)",
+            name, sigma);
 
   status = rng_bin_test (r, &sigma);
 
   gsl_test (status,
-	    "%s, bin test within acceptable chisq (observed %.2g sigma)",
-	    name, sigma);
+            "%s, bin test within acceptable chisq (observed %.2g sigma)",
+            name, sigma);
 
-  gsl_rng_set (r, 1);	/* set seed to 1 */
+  gsl_rng_set (r, 1);   /* set seed to 1 */
   status = rng_max_test (r, &kmax, ran_max);
 
-  gsl_rng_set (r, 1);	/* set seed to 1 */
+  gsl_rng_set (r, 1);   /* set seed to 1 */
   status |= rng_min_test (r, &kmin, ran_min, ran_max);
 
-  gsl_rng_set (r, 1);	/* set seed to 1 */
+  gsl_rng_set (r, 1);   /* set seed to 1 */
   status |= rng_sum_test (r, &sigma);
 
-  gsl_rng_set (r, 12345);	/* set seed to a "typical" value */
+  gsl_rng_set (r, 12345);       /* set seed to a "typical" value */
   status |= rng_max_test (r, &kmax, ran_max);
 
-  gsl_rng_set (r, 12345);	/* set seed to a "typical" value */
+  gsl_rng_set (r, 12345);       /* set seed to a "typical" value */
   status |= rng_min_test (r, &kmin, ran_min, ran_max);
 
-  gsl_rng_set (r, 12345);	/* set seed to a "typical" value */
+  gsl_rng_set (r, 12345);       /* set seed to a "typical" value */
   status |= rng_sum_test (r, &sigma);
 
   gsl_test (status, "%s, maximum and sum tests for non-default seeds", name);
@@ -399,7 +474,7 @@ rng_max_test (gsl_rng * r, unsigned long int *kmax, unsigned long int ran_max)
     {
       unsigned long int k = gsl_rng_get (r);
       if (k > max)
-	max = k;
+        max = k;
     }
 
   *kmax = max;
@@ -414,7 +489,7 @@ rng_max_test (gsl_rng * r, unsigned long int *kmax, unsigned long int ran_max)
 
 int
 rng_min_test (gsl_rng * r, unsigned long int *kmin, 
-	      unsigned long int ran_min, unsigned long int ran_max)
+              unsigned long int ran_min, unsigned long int ran_max)
 {
   unsigned long int actual_uncovered;
   double expect_uncovered;
@@ -426,7 +501,7 @@ rng_min_test (gsl_rng * r, unsigned long int *kmin,
     {
       unsigned long int k = gsl_rng_get (r);
       if (k < min)
-	min = k;
+        min = k;
     }
 
   *kmin = min;
@@ -504,13 +579,13 @@ rng_bin_test (gsl_rng * r, double *sigma)
   for (i = BINS; i < BINS+EXTRA; i++)
     {
       if (count[i] != 0)
-	{
-	  status = 1 ;
-	  gsl_test (status, 
-		    "%s, wrote outside range in bin test "
-		    "(%d observed vs %d expected)",
-		    gsl_rng_name(r), i, BINS - 1);
-	}
+        {
+          status = 1 ;
+          gsl_test (status, 
+                    "%s, wrote outside range in bin test "
+                    "(%d observed vs %d expected)",
+                    gsl_rng_name(r), i, BINS - 1);
+        }
     }
 
   return status;
