@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* steffenson.c -- steffenson root finding algorithm 
@@ -107,7 +107,7 @@ steffenson_iterate (void * vstate, gsl_function_fdf * fdf, double * root)
 
   if (!finite (f_new))
     {
-      GSL_ERROR ("function not continuous", GSL_EBADFUNC);
+      GSL_ERROR ("function value is not finite", GSL_EBADFUNC);
     }
 
   if (state->count < 3)
@@ -128,7 +128,7 @@ steffenson_iterate (void * vstate, gsl_function_fdf * fdf, double * root)
 
   if (!finite (df_new))
     {
-      GSL_ERROR ("function not differentiable", GSL_EBADFUNC);
+      GSL_ERROR ("derivative value is not finite", GSL_EBADFUNC);
     }
       
   return GSL_SUCCESS;
