@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* Author:  G. Jungman */
@@ -488,7 +488,7 @@ dilogc_unitdisk(double x, double y, gsl_sf_result * real_dl, gsl_sf_result * ima
 {
   static const double MAGIC_SPLIT_VALUE = 0.732;
   static const double zeta2 = M_PI*M_PI/6.0;
-  const double r = sqrt(x*x + y*y);
+  const double r = hypot(x, y);
 
   if(x > MAGIC_SPLIT_VALUE)
   {
@@ -498,7 +498,7 @@ dilogc_unitdisk(double x, double y, gsl_sf_result * real_dl, gsl_sf_result * ima
      */
     const double x_tmp = 1.0 - x;
     const double y_tmp =     - y;
-    const double r_tmp = sqrt(x_tmp*x_tmp + y_tmp*y_tmp);
+    const double r_tmp = hypot(x_tmp, y_tmp);
     /* const double cos_theta_tmp = x_tmp/r_tmp; */
     /* const double sin_theta_tmp = y_tmp/r_tmp; */
 
