@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* Author:  G. Jungman */
@@ -259,7 +259,7 @@ static struct {int n; double f; long i; } doub_fact_table[DOUB_FACT_TABLE_SIZE]
   { 3,  3.000000000000000000000000000,    3L    },
   { 4,  8.000000000000000000000000000,    8L    },
   { 5,  15.00000000000000000000000000,    15L   },
-  { 6,  48.00000000000000000000000000,    48L	},
+  { 6,  48.00000000000000000000000000,    48L   },
   { 7,  105.0000000000000000000000000,    105L  },
   { 8,  384.0000000000000000000000000,    384L  },
   { 9,  945.0000000000000000000000000,    945L  },
@@ -1221,12 +1221,12 @@ int gsl_sf_lngamma_sgn_e(double x, gsl_sf_result * result_lg, double * sgn)
       if(x < INT_MIN + 2.0) {
         result_lg->val = 0.0;
         result_lg->err = 0.0;
-	*sgn = 0.0;
-	GSL_ERROR ("error", GSL_EROUND);
+        *sgn = 0.0;
+        GSL_ERROR ("error", GSL_EROUND);
       }
       else {
         int N = -(int)(x - 0.5);
-	double eps = x + N;
+        double eps = x + N;
         return lngamma_sgn_sing(N, eps, result_lg, sgn);
       }
     }
@@ -1255,8 +1255,8 @@ gsl_sf_gamma_e(const double x, gsl_sf_result * result)
   if(x < 0.5) {
     int rint_x = (int)floor(x+0.5);
     double f_x = x - rint_x;
-    double sgn = ( GSL_IS_EVEN(rint_x) ? 1.0 : -1.0 );
-    double sin_term = sgn * sin(M_PI * f_x) / M_PI;
+    double sgn_gamma = ( GSL_IS_EVEN(rint_x) ? 1.0 : -1.0 );
+    double sin_term = sgn_gamma * sin(M_PI * f_x) / M_PI;
 
     if(sin_term == 0.0) {
       DOMAIN_ERROR(result);
@@ -1266,8 +1266,8 @@ gsl_sf_gamma_e(const double x, gsl_sf_result * result)
       gamma_xgthalf(1.0-x, &g);
       if(fabs(sin_term) * g.val * GSL_DBL_MIN < 1.0) {
         result->val  = 1.0/(sin_term * g.val);
-	result->err  = fabs(g.err/g.val) * fabs(result->val);
-	result->err += 2.0 * GSL_DBL_EPSILON * fabs(result->val);
+        result->err  = fabs(g.err/g.val) * fabs(result->val);
+        result->err += 2.0 * GSL_DBL_EPSILON * fabs(result->val);
         return GSL_SUCCESS;
       }
       else {
@@ -1348,7 +1348,11 @@ gsl_sf_gammainv_e(const double x, gsl_sf_result * result)
 {
   /* CHECK_POINTER(result) */
 
-  if(x < 0.5) {
+  if (x <= 0.0 && x == floor(x)) { /* negative integer */
+    result->val = 0.0;
+    result->err = 0.0;
+    return GSL_SUCCESS;
+  } else if(x < 0.5) {
     gsl_sf_result lng;
     double sgn;
     int stat_lng = gsl_sf_lngamma_sgn_e(x, &lng, &sgn);
@@ -1585,19 +1589,36 @@ int gsl_sf_choose_e(unsigned int n, unsigned int m, gsl_sf_result * result)
     result->err = 0.0;
     return GSL_SUCCESS;
   }
-  else {
-    double prod = 1.0;
-    int k;
-    for(k=n; k>=m+1; k--) {
-      double tk = (double)k / (double)(k-m);
-      if(tk > GSL_DBL_MAX/prod) {
-        OVERFLOW_ERROR(result);
-      }
-      prod *= tk;
-    }
-    result->val = prod;
-    result->err = 2.0 * GSL_DBL_EPSILON * prod * fabs(n-m);
+  else if (n <= FACT_TABLE_MAX) {
+    result->val = (fact_table[n].f / fact_table[m].f) / fact_table[n-m].f;
+    result->err = 6.0 * GSL_DBL_EPSILON * fabs(result->val);
     return GSL_SUCCESS;
+  } else {
+    if(m*2 < n) m = n-m;
+
+    if (n - m < 64)  /* compute product for a manageable number of terms */
+      {
+        double prod = 1.0;
+        unsigned int k;
+        
+        for(k=n; k>=m+1; k--) {
+          double tk = (double)k / (double)(k-m);
+          if(tk > GSL_DBL_MAX/prod) {
+            OVERFLOW_ERROR(result);
+          }
+          prod *= tk;
+        }
+        result->val = prod;
+        result->err = 2.0 * GSL_DBL_EPSILON * prod * fabs(n-m);
+        return GSL_SUCCESS;
+      }
+    else
+      {
+        gsl_sf_result lc;
+        const int stat_lc = gsl_sf_lnchoose_e (n, m, &lc);
+        const int stat_e  = gsl_sf_exp_err_e(lc.val, lc.err, result);
+        return GSL_ERROR_SELECT_2(stat_lc, stat_e);
+      }
   }
 }
 
