@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* Author:  G. Jungman */
@@ -194,19 +194,23 @@ int test_bessel(void)
   TEST_SF(s,  gsl_sf_bessel_yl_e, (100,    100.0, &r),  -0.0229838504915622811,   TEST_TOL1, GSL_SUCCESS);
   TEST_SF(s,  gsl_sf_bessel_yl_e, (2000, 1048576.0, &r), 5.9545201447146155e-07,  TEST_SQRT_TOL0, GSL_SUCCESS);
 
-
+  TEST_SF(s, gsl_sf_bessel_i0_scaled_e, (0.0, &r), 1.0, TEST_TOL0, GSL_SUCCESS);
   TEST_SF(s, gsl_sf_bessel_i0_scaled_e, (0.1, &r), 0.9063462346100907067, TEST_TOL0, GSL_SUCCESS);
   TEST_SF(s, gsl_sf_bessel_i0_scaled_e, (2.0, &r), 0.24542109027781645493, TEST_TOL0, GSL_SUCCESS);
   TEST_SF(s, gsl_sf_bessel_i0_scaled_e, (100.0, &r), 0.005000000000000000000, TEST_TOL0, GSL_SUCCESS);
 
+  TEST_SF(s, gsl_sf_bessel_i1_scaled_e, (0.0, &r), 0.0, TEST_TOL0, GSL_SUCCESS);
   TEST_SF(s, gsl_sf_bessel_i1_scaled_e, (0.1, &r), 0.030191419289002226846, TEST_TOL0, GSL_SUCCESS);
   TEST_SF(s, gsl_sf_bessel_i1_scaled_e, (2.0, &r), 0.131868364583275317610, TEST_TOL0, GSL_SUCCESS);
   TEST_SF(s, gsl_sf_bessel_i1_scaled_e, (100.0, &r), 0.004950000000000000000, TEST_TOL0, GSL_SUCCESS);
 
+  TEST_SF(s, gsl_sf_bessel_i2_scaled_e, (0.0, &r), 0.0, TEST_TOL0, GSL_SUCCESS);
   TEST_SF(s, gsl_sf_bessel_i2_scaled_e, (0.1, &r), 0.0006036559400239012567, TEST_TOL0, GSL_SUCCESS);
   TEST_SF(s, gsl_sf_bessel_i2_scaled_e, (2.0, &r), 0.0476185434029034785100, TEST_TOL0, GSL_SUCCESS);
   TEST_SF(s, gsl_sf_bessel_i2_scaled_e, (100.0, &r), 0.0048515000000000000000, TEST_TOL0, GSL_SUCCESS);
 
+  TEST_SF(s, gsl_sf_bessel_il_scaled_e, (   0, 0.0,   &r), 1.0, TEST_TOL0, GSL_SUCCESS);
+  TEST_SF(s, gsl_sf_bessel_il_scaled_e, (   1, 0.0,   &r), 0.0, TEST_TOL0, GSL_SUCCESS);
   TEST_SF(s, gsl_sf_bessel_il_scaled_e, (   4, 0.001, &r), 1.0571434341190365013e-15, TEST_TOL0, GSL_SUCCESS);
   TEST_SF(s, gsl_sf_bessel_il_scaled_e, (   4,   0.1, &r), 9.579352242057134927e-08,  TEST_TOL1, GSL_SUCCESS);
   TEST_SF(s, gsl_sf_bessel_il_scaled_e, (   5,   2.0, &r), 0.0004851564602127540059,  TEST_TOL0, GSL_SUCCESS);
@@ -380,11 +384,12 @@ int test_bessel(void)
   s += sa;
 
   sa = 0;
-  gsl_sf_bessel_jl_steed_array(50, 1.0, J);
+  gsl_sf_bessel_jl_steed_array(99, 1.0, J);
   sa += ( test_sf_frac_diff(J[0],  0.84147098480789650670   ) > TEST_TOL0 );
   sa += ( test_sf_frac_diff(J[1],  0.30116867893975678925   ) > TEST_TOL0 );
   sa += ( test_sf_frac_diff(J[10], 7.116552640047313024e-11 ) > TEST_TOL0 );
   sa += ( test_sf_frac_diff(J[50], 3.615274717489787311e-81 ) > TEST_TOL0 );
+  sa += ( test_sf_frac_diff(J[80], 1.136352423414503264e-144 ) > TEST_TOL1 );
   gsl_test(sa, "  gsl_sf_bessel_jl_steed_array");
   s += sa;
 
@@ -397,6 +402,15 @@ int test_bessel(void)
   gsl_test(sa, "  gsl_sf_bessel_yl_array");
   s += sa;
 
+  {
+    double Y0[1];
+    sa = 0;
+    gsl_sf_bessel_yl_array(0, 1.0, Y0);
+    sa += ( test_sf_frac_diff(Y0[0],  -0.5403023058681397174 ) > TEST_TOL0 );
+    gsl_test(sa, "  gsl_sf_bessel_yl_array (lmax=0)");
+    s += sa;
+  }
+
   sa = 0;
   gsl_sf_bessel_il_scaled_array(50, 1.0, I);
   sa += ( test_sf_frac_diff(I[0],  0.43233235838169365410 ) > TEST_TOL2 );
@@ -406,6 +420,15 @@ int test_bessel(void)
   gsl_test(sa, "  gsl_sf_bessel_il_scaled_array");
   s += sa;
 
+  sa = 0;
+  gsl_sf_bessel_il_scaled_array(50, 0.0, I);
+  sa += ( test_sf_frac_diff(I[0],  1.0 ) > TEST_TOL2 );
+  sa += ( test_sf_frac_diff(I[1],  0.0 ) > TEST_TOL2 );
+  sa += ( test_sf_frac_diff(I[10], 0.0 ) > TEST_TOL2 );
+  sa += ( test_sf_frac_diff(I[50], 0.0 ) > TEST_TOL2 );
+  gsl_test(sa, "  gsl_sf_bessel_il_scaled_array (L=0)");
+  s += sa;
+
   sa = 0;
   gsl_sf_bessel_kl_scaled_array(50, 1.0, K);
   sa += ( test_sf_frac_diff(K[0],  1.5707963267948966192     ) > TEST_TOL0 );
@@ -415,6 +438,15 @@ int test_bessel(void)
   gsl_test(sa, "  gsl_sf_bessel_kl_scaled_array");
   s += sa;
 
+  {
+    double K0[1];
+    sa = 0;
+    gsl_sf_bessel_kl_scaled_array(0, 1.0, K0);
+    sa += ( test_sf_frac_diff(K[0],  1.5707963267948966192     ) > TEST_TOL0 );
+    gsl_test(sa, "  gsl_sf_bessel_kl_scaled_array (lmax=0)");
+    s += sa;
+  }
+
   sa = 0;
   sa += ( gsl_sf_bessel_zero_J0_e(0, &r) != GSL_EINVAL );
   sa += ( r.val != 0.0 );
