@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* Author:  G. Jungman */
@@ -179,7 +179,7 @@ gsl_sf_transport_2_e(const double x, gsl_sf_result * result)
   }
   else if(x < 3.0*GSL_SQRT_DBL_EPSILON) {
     result->val = x;
-    result->err = x;
+    result->err = GSL_DBL_EPSILON*fabs(x) + x*x/2.0;
     return GSL_SUCCESS;
   }
   else if(x <= 4.0) {
